@@ -7,6 +7,8 @@ import logging
 import os
 import sys
 import copy
+import threading
+import time
 
 from typing import Dict, List, Optional
 from joblib import Parallel, delayed, parallel_backend
@@ -86,6 +88,12 @@ def get_snowflake_statics(config):
     return table_cache, file_format_type
 
 
+def flush_timer(batch_wait_limit_seconds, flush_event):
+    while True:
+        time.sleep(batch_wait_limit_seconds)
+        flush_event.set()
+
+
 # pylint: disable=too-many-locals,too-many-branches,too-many-statements,invalid-name
 def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatTypes = None) -> None:
     """Main loop to read and consume singer messages from stdin
@@ -116,10 +124,14 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
     batch_size_rows = config.get('batch_size_rows', DEFAULT_BATCH_SIZE_ROWS)
     batch_wait_limit_seconds = config.get(
         'batch_wait_limit_seconds', DEFAULT_BATCH_WAIT_TIME)
-    flush_timestamp = datetime.utcnow()
     archive_load_files = config.get('archive_load_files', False)
     archive_load_files_data = {}
 
+    flush_event = threading.Event()
+    flush_thread = threading.Thread(target=flush_timer, args=(batch_wait_limit_seconds, flush_event))
+    flush_thread.daemon = True
+    flush_thread.start()
+
     # Loop over lines from stdin
     for line in lines:
         try:
@@ -201,8 +213,7 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
                 flush = True
                 LOGGER.info("Flush triggered by batch_size_rows (%s) reached in %s",
                             batch_size_rows, stream)
-            elif (batch_wait_limit_seconds and
-                  datetime.utcnow() >= (flush_timestamp + timedelta(seconds=batch_wait_limit_seconds))):
+            elif flush_event.is_set():
                 flush = True
                 LOGGER.info("Flush triggered by batch_wait_limit_seconds (%s)",
                             batch_wait_limit_seconds)
@@ -225,7 +236,8 @@ def persist_lines(config, lines, table_cache=None, file_format_type: FileFormatT
                     archive_load_files_data,
                     filter_streams=filter_streams)
 
-                flush_timestamp = datetime.utcnow()
+                # Reset the flush_event
+                flush_event.clear()
 
                 # emit last encountered state
                 emit_state(copy.deepcopy(flushed_state))
